//==============================================================================
//
// Title:       Example 2
// Purpose:     Error Checking
//
// Created on:  09/01/2008 by David Judge.
// Copyright:   Anritsu. All Rights Reserved.
//
//==============================================================================

//==============================================================================
// Include files
#include <ansi_c.h>
#include <visa.h>
#include <userint.h>
#include "au37xxx.h"

ViSession session;
ViStatus checkErr (ViStatus status);
#define CHECKERR(fCal) \
    if (au37xxx_status = checkErr((fCal)), au37xxx_status < VI_SUCCESS) \
        goto Error; else


int main (int argc, char *argv[])
{
    
    ViStatus status;
    ViUInt32 read_count;
    ViStatus    au37xxx_status   = VI_SUCCESS;
    ViChar l_buffer[50];
    ViChar* p2Manf = NULL;
    ViChar* p2Model = NULL;
    ViChar* p2Ser = NULL;
    ViChar* p2Firm = NULL;
	
	printf("Example 2: Testing for Errors\n\n");
    CHECKERR(au37xxx_init ("VectorStar_Test", VI_TRUE, VI_FALSE, &session));
    
    //Use Native VNA Error Checking
    CHECKERR(au37xxx_write (session, "LANG NATIVE"));
    
    //First send a known good command
    CHECKERR(au37xxx_write (session, "*IDN?"));
    CHECKERR(viRead (session, (ViPBuf)l_buffer, 50, &read_count));
    
    //Send an OID - also a good command
    CHECKERR(au37xxx_write (session, "OID"));
    CHECKERR(viRead (session, (ViPBuf)l_buffer, 50, &read_count));
    
    //This command is not a valid VNA command and should generate an error
    CHECKERR(au37xxx_write (session, "ABC"));
    au37xxx_close(session);
	
    printf("\n\nHit return to exit:");
    getc(stdin);
    
    return 0;
    
Error:
    printf("\n\nDetected an Error--Hit return to exit:");
    getc(stdin);
    
    return 0;
}


ViStatus checkErr (ViStatus status)
{
    ViChar  error_message [256];
    ViChar  error_buffer [1024];
    ViUInt16 stb;
    ViUInt16 VNA_ERROR = 4;
    
    if (status >= 0) 
        viReadSTB (session, &stb);
    
    //check if stb & VNA_ERROR is set
    
    if ((status < VI_SUCCESS) || ((stb & VNA_ERROR) > 0))
    {
        au37xxx_error_message (session, status, error_message);
        sprintf (error_buffer, "Primary Error: 0x%08X, %s\n", status, error_message);
        printf ("%s\n", error_buffer);
        au37xxx_error_query (session, error_message);
        SetWaitCursor (0);
        sprintf (error_buffer, "Instrument Error: %s\n", error_message);
        printf ("%s\n", error_buffer);
        au37xxx_close(session);
        session = 0;
    }
    return status;
}
