
//==============================================================================
//
// Title:       Example 4
// Purpose:     Acquire Trace Data
//
// Created on:  09/02/2008 by David Judge.
// Copyright:   Anritsu. All Rights Reserved.
//
//==============================================================================

//==============================================================================
// Include files
#include <ansi_c.h>
#include <visa.h>
#include <userint.h>
#include <formatio.h>
#include "au37xxx.h"

ViSession session;
ViStatus checkErr (ViStatus status);
#define CHECKERR(fCal) \
    if (au37xxx_status = checkErr((fCal)), au37xxx_status < VI_SUCCESS) \
        goto Error; else


int main (int argc, char *argv[])
{
    
    ViInt32 retCount;
    ViStatus status;
    ViUInt32 read_count;
    ViStatus au37xxx_status = VI_SUCCESS;
    FILE* fp; 
    ViChar readBuffer[500000];
    ViReal64 fdata[201];
    ViReal64 chanData[402];
    ViReal64 lmData[201];
    ViReal64 phaseData[201];
    int i, ii = 0;
    
    CHECKERR(au37xxx_init ("VectorStar_Test", VI_FALSE, VI_FALSE, &session));
    CHECKERR(au37xxx_configureChannel (session, 2));
    CHECKERR(au37xxx_configureSweep (session, 201, AU37XXX_SWEEP_NORMAL));
    CHECKERR(au37xxx_readFrequencyValues (session, 201,fdata,&retCount));
    CHECKERR(au37xxx_readChannelData (session, 2, AU37XXX_DATA_FINAL, 402, chanData, &retCount));

    au37xxx_close(session);
    
    fp = fopen(".\\chanData.txt","w") ;
    
    for (i=0;i<201;i++) 
    {
        lmData[i] = chanData[ii++];
        phaseData[i] = chanData[ii++];
        fprintf(fp,"%e %10.4f\t%10.4f\n",fdata[i],lmData[i],phaseData[i]);
    }
    
    fclose(fp);
            
    
    
Error:
    printf("\n\nHit return to exit:");
    getc(stdin);
    return 0;
}


ViStatus checkErr (ViStatus status)
{
    ViChar  error_message [256];
    ViChar  error_buffer [1024];
    ViUInt16 stb;
    ViUInt16 VNA_ERROR = 4;
    
    if (status >= 0) 
        viReadSTB (session, &stb);
    
    //check if stb & VNA_ERROR is set
    
    if ((status < VI_SUCCESS) || ((stb & VNA_ERROR) > 0))
    {
        au37xxx_error_message (session, status, error_message);
        sprintf (error_buffer, "Primary Error: 0x%08X, %s\n", status, error_message);
        printf ("%s\n", error_buffer);
        au37xxx_error_query (session, error_message);
        SetWaitCursor (0);
        sprintf (error_buffer, "Instrument Error: %s\n", error_message);
        printf ("%s\n", error_buffer);
        au37xxx_close(session);
        session = 0;
    }
    return status;
}



