/*----------------------------------------------------------------------------*/
/* Using FFT to do a 2D FFT                                                   */
/*----------------------------------------------------------------------------*/
#define HELP_MSG "\
This program is adapted from the Smith Chart Demo in samples\\apps\\smithchart. \
We use the smithchart fp found in toolslib\\toolbox\\smith.fp."


/*----------------------------------------------------------------------------*/
/* Includes                                                                   */
/*----------------------------------------------------------------------------*/
#include <ansi_c.h>
#include <visa.h>
#include <userint.h>
#include <math.h>
#include <analysis.h>
#include "au37xxx.h"
#include "smithdem.h"
#include "smith.h"

ViSession session;
ViStatus checkErr (ViStatus status);
#define CHECKERR(fCal) \
    if (au37xxx_status = checkErr((fCal)), au37xxx_status < VI_SUCCESS) \
        goto Error; else


/*----------------------------------------------------------------------------*/
/* Defines                                                                    */
/*----------------------------------------------------------------------------*/
#define PI  3.1415926535897932384626433832795028841971

#define IMPEDANCE_COLOR  VAL_RED
#define ADMITTANCE_COLOR VAL_DK_MAGENTA
#define REFLECTION_COLOR VAL_DK_GREEN
#define CURRENT_COLOR    VAL_DK_CYAN

/*----------------------------------------------------------------------------*/
/* Prototypes                                                                 */
/*----------------------------------------------------------------------------*/
static void RefreshSmithChart(void);
static void Init(void);

static int      panelHandle;
static Complex  gZ, gY;

/*----------------------------------------------------------------------------*/
/* Main                                                                       */
/*----------------------------------------------------------------------------*/
int main (int argc, char *argv[])
{
    if (InitCVIRTE (0, argv, 0) == 0)
        return -1;    /* out of memory */
    if ((panelHandle = LoadPanel (0, "smithdem.uir", PANEL)) < 0)
        return -1;
    SMITH_ConvertFromGraph (panelHandle, PANEL_GRAPH, 1, 0, 0, 0, 0);
    Init();

    DisplayPanel (panelHandle);
    RunUserInterface ();

    SMITH_DiscardChart (panelHandle, PANEL_GRAPH);
    CloseCVIRTE ();
    return 0;
}

/*----------------------------------------------------------------------------*/
/* Init                                                                       */
/*----------------------------------------------------------------------------*/
static void Init(void){

    ViInt32 retCount;
    ViStatus status;
    ViUInt32 read_count;
    ViStatus au37xxx_status = VI_SUCCESS;

    ViReal64 fdata[201];
    ViReal64 chanData[402];
    ViReal64 impData[201];
    ViReal64 reactData[201];
    int i, ii = 0;
    
    CHECKERR(au37xxx_init ("VectorStar_Test", VI_FALSE, VI_FALSE, &session));
    CHECKERR(au37xxx_configureChannel (session, 1));
    CHECKERR(au37xxx_configureSweep (session, 201, AU37XXX_SWEEP_NORMAL));
    CHECKERR(au37xxx_readFrequencyValues (session, 201,fdata,&retCount));
    CHECKERR(au37xxx_readChannelData (session, 1, AU37XXX_DATA_FINAL, 402, chanData, &retCount));

    au37xxx_close(session);
    
    
    for (i=0;i<201;i++) 
    {
        impData[i] = chanData[ii++];
        reactData[i] = chanData[ii++];
        gZ.Real = impData[i]/50.0;
        gZ.Im = reactData[i]/50.0;
    
        SMITH_PlotImpedancePoint(panelHandle, PANEL_GRAPH, &gZ, VAL_SOLID_CIRCLE, IMPEDANCE_COLOR);
    }
    
    
Error:
    
}


/*----------------------------------------------------------------------------*/
/* Quit                                                                       */
/*----------------------------------------------------------------------------*/
int Quit (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2) {
    switch (event) {
        case EVENT_COMMIT:
            QuitUserInterface (0);
        break;
    }
    return 0;
}

/*----------------------------------------------------------------------------*/
/* Help                                                                       */
/*----------------------------------------------------------------------------*/
int CVICALLBACK Help (int panel, int control, int event,
        void *callbackData, int eventData1, int eventData2)
{
    switch (event) {
        case EVENT_RIGHT_CLICK:
        case EVENT_COMMIT:
            MessagePopup ("Smith Chart Demo", HELP_MSG);
        break;
    }
    return 0;
}

ViStatus checkErr (ViStatus status)
{
    ViChar  error_message [256];
    ViChar  error_buffer [1024];
    ViUInt16 stb = 0;
    ViUInt16 VNA_ERROR = 4;
    
    if (status >= 0)
        viReadSTB (session, &stb);
    
    //check if stb & VNA_ERROR is set
    
    if ((status < VI_SUCCESS) || ((stb & VNA_ERROR) > 0))
    {
        au37xxx_error_message (session, status, error_message);
        sprintf (error_buffer, "Primary Error: 0x%08X, %s\n", status, error_message);
        printf ("%s\n", error_buffer);
        au37xxx_error_query (session, error_message);
        SetWaitCursor (0);
        sprintf (error_buffer, "Instrument Error: %s\n", error_message);
        printf ("%s\n", error_buffer);
        au37xxx_close(session);
        session = 0;
    }
    return status;
}
