//==============================================================================
//
// Title:       Example 6
// Purpose:     Output S2P file
//
// Created on:  09/02/2008 by David Judge.
// Copyright:   Anritsu. All Rights Reserved.
//
//==============================================================================
// Include files
#include <ansi_c.h>
#include <visa.h>
#include <userint.h>
#include <formatio.h>
#include "au37xxx.h"

ViSession session;
ViStatus checkErr (ViStatus status);
#define CHECKERR(fCal) \
    if (au37xxx_status = checkErr((fCal)), au37xxx_status < VI_SUCCESS) \
        goto Error; else


int main (int argc, char *argv[])
{
    
    ViInt32 retCount;
    
    ViStatus status;
    ViUInt32 read_count;
    ViStatus au37xxx_status = VI_SUCCESS;
    int fileHandle; 
    ViChar readBuffer[100000];
    
    CHECKERR(au37xxx_init ("VectorStar_Test", VI_FALSE, VI_TRUE, &session));
    CHECKERR(au37xxx_write(session,"LANG NATIVE"));
    CHECKERR(au37xxx_write(session,":SENSE:SWEEP:POINTS 25"));
    CHECKERR(au37xxx_write(session,":FORM:SNP:FREQ HZ"));
    CHECKERR(au37xxx_write(session,":FORM:SNP:PAR REIM"));
    CHECKERR(au37xxx_write(session,"TRS;WFS;OS2P"));    
            
    CHECKERR(au37xxx_readAsciiARBBlock(session,100000,readBuffer,&retCount));
    au37xxx_close(session);
            
            
    fileHandle = OpenFile (".\\dave.s2p", VAL_WRITE_ONLY, VAL_OPEN_AS_IS, VAL_ASCII);
    WriteFile (fileHandle, readBuffer, retCount);
    CloseFile (fileHandle);

Error:
    printf("\n\nHit return to exit:");
    getc(stdin);
    return 0;
}

ViStatus checkErr (ViStatus status)
{
    ViChar  error_message [256];
    ViChar  error_buffer [1024];
    ViUInt16 stb;
    ViUInt16 VNA_ERROR = 4;
    
    if (status >= 0) 
        viReadSTB (session, &stb);
    
    //check if stb & VNA_ERROR is set
    
    if ((status < VI_SUCCESS) || ((stb & VNA_ERROR) > 0))
    {
        au37xxx_error_message (session, status, error_message);
        sprintf (error_buffer, "Primary Error: 0x%08X, %s\n", status, error_message);
        printf ("%s\n", error_buffer);
        au37xxx_error_query (session, error_message);
        SetWaitCursor (0);
        sprintf (error_buffer, "Instrument Error: %s\n", error_message);
        printf ("%s\n", error_buffer);
        au37xxx_close(session);
        session = 0;
    }
    return status;
}

